@@ -1,5 +1,6 @@
 from tsdoc0.python.model import Model
 from tsdoc0.python.segment import Segment
+from tsdoc0.python.utils import repr_parent
 from typing import Final
 from typing import Iterable
 from typing import Optional
@@ -16,7 +17,7 @@ def _tuple(iterable: Iterable[str]) -> Tuple[str, ...]:
 
 @attr.s(auto_attribs=True, kw_only=True)
 class Keywords(Segment):
-    parent: Optional[Model] = attr.ib(eq=False)
+    parent: Optional[Model] = attr.ib(eq=False, repr=repr_parent)
     indentation: Final[str]  # type: ignore[misc]
     terms: Final[Tuple[str, ...]] = attr.ib(converter=_tuple)
 
