@@ -77,6 +77,7 @@ class VocabularyTerm(Segment):
             "Function": "A named code action that can be used in a program",
             "Greater than": "Is the left value bigger than the right value?",
             "Header comment": 'A multi-line comment at the top of a program surrounded by `"""` marks',  # noqa: E501
+            "Identity comparison": "Check whether two different variables refer to the same data",  # noqa: E501
             "if statement": "Runs a section of code when the condition is true",
             "Increment": "Increase a variable by an amount",
             "Index": "The zero-based position of an element in a collection",
@@ -92,16 +93,21 @@ class VocabularyTerm(Segment):
             "Library": "A collection of code from outside the program",
             "List": "A changeable collection of ordered elements",
             "List append": "Add an element to the end of a list",
+            "List concatenation": "Create a new list by joining two lists together",
             "List delete": "Take an element out of a list by its index",
+            "List equality comparison": "Check whether two lists contain all of the same elements in the same order",  # noqa: E501
             "List extend": "Copy all elements of one list to the end of another list",
             "List insert": "Add an element to a list at a position",
             "List remove": "Take an element out of a list by its value",
+            "List repetition": "Create a new list from multiple copies of an existing list",  # noqa: E501
             "Literal": "A value you can literally see",
             "Logical operator": "Combines or modifies a boolean",
             "Loop else clause": "A clause following a loop that runs unless the loop ends with break",  # noqa: E501
             "Loop variable": "A variable whose value changes based on the iteration of a loop",  # noqa: E501
             "Main loop": "Keeps a window open and updated",
+            "Maximum": "The largest value in a collection",
             "Method": "A function that belongs to an instance",
+            "Minimum": "The smallest value in a collection",
             "Modular design": "Composing a system with independent parts",
             "Modulo operator": "Calculates the remainder after division",
             "Multiple assignment": "Assigning more than one variable with the same operator",  # noqa: E501
@@ -113,9 +119,11 @@ class VocabularyTerm(Segment):
             "Output": "Information a program gives to the user, such as text",
             "random library": "A library with code to create unpredictable values",
             "range": "A sequence of integers with a start and an end",
+            "Reference": "A name that points to data",
             "Retrospective": "A formal review of the successes and failures of recent work",  # noqa: E501
             "Return value": "Information given back by a function",
             "Scope": "The set of work planned for a specific time period",  # noqa: E501
+            "Sort": "Arrange the elements in a collection in ascending order",
             "Speed": "Attributes that control how fast and what direction an instance moves on screen",  # noqa: E501
             "Sprite": "An on-screen graphic based on an image",
             "Spritesheet": "An image designed to be broken apart and used as an animation",  # noqa: E501
@@ -188,6 +196,7 @@ class VocabularyTerm(Segment):
             "Function": "1.2.1",
             "Greater than": "2.1.2",
             "Header comment": "1.1.2",
+            "Identity comparison": "4.3.2",
             "if statement": "2.1.1",
             "Increment": "1.4.1",
             "Index": "4.1.2",
@@ -203,16 +212,21 @@ class VocabularyTerm(Segment):
             "Library": "1.2.1",
             "List": "4.1.1",
             "List append": "4.2.2",
+            "List concatenation": "4.3.2",
             "List delete": "4.2.2",
+            "List equality comparison": "4.3.2",
             "List extend": "4.2.2",
             "List insert": "4.2.2",
             "List remove": "4.2.2",
+            "List repetition": "4.3.2",
             "Literal": "1.3.1",
             "Logical operator": "2.4.1",
             "Loop else clause": "3.2.1",
             "Loop variable": "3.7.1",
             "Main loop": "3.4.1",
+            "Maximum": "4.3.1",
             "Method": "3.3.1",
+            "Minimum": "4.3.1",
             "Modular design": "2.pl3.1",
             "Modulo operator": "2.3.2",
             "Multiple assignment": "3.6.2",
@@ -224,9 +238,11 @@ class VocabularyTerm(Segment):
             "Output": "1.1.1",
             "random library": "2.3.1",
             "range": "3.7.1",
+            "Reference": "4.3.2",
             "Retrospective": "2.pl3.1",
             "Return value": "1.4.2",
             "Scope": "2.pl3.1",
+            "Sort": "4.3.1",
             "Speed": "3.5.1",
             "Sprite": "3.4.1",
             "Spritesheet": "3.5.1",
